# abattlemetrics

[![PyPI](https://img.shields.io/pypi/v/abattlemetrics?label=View%20on%20pypi&style=flat-square)](https://pypi.org/project/abattlemetrics/)
[![](https://img.shields.io/github/actions/workflow/status/thegamecracks/abattlemetrics/publish.yml?style=flat-square&logo=uv&label=build)](https://docs.astral.sh/uv/)
[![](https://img.shields.io/github/actions/workflow/status/thegamecracks/abattlemetrics/pyright-lint.yml?style=flat-square&label=pyright)](https://microsoft.github.io/pyright/#/)
[![](https://img.shields.io/github/actions/workflow/status/thegamecracks/abattlemetrics/ruff-check.yml?style=flat-square&logo=ruff&label=lints)](https://docs.astral.sh/ruff/)
[![](https://img.shields.io/github/actions/workflow/status/thegamecracks/abattlemetrics/ruff-format.yml?style=flat-square&logo=ruff&label=style)](https://docs.astral.sh/ruff/)

An asyncio wrapper for the battlemetrics API.

## Installation

To install the latest release from PyPI (requires Python 3.8 or above):

```sh
pip install abattlemetrics
```

To install the development version from GitHub (requires Git):

```sh
pip install git+https://github.com/thegamecracks/abattlemetrics
```

## Notice

I am currently not maintaining this project as this wrapper has
been sufficient for my needs. Many endpoints have not been implemented,
but I will still accept PRs following the [contributing guide](CONTRIBUTING.md).

## License

This project uses the [MIT](LICENSE) license.
